@@ -24,6 +24,6 @@
 #
 ###############################################################################
 
-__version__ = '23.6.2'
+__version__ = "25.12.1"
 
-__build__ = '00000000-0000000'
+__build__ = "00000000-0000000"
